Copilot Node.js server stripped from [copilot.vim] and published on [NPM][copilot-node-server-npm].

To start the server, execute `bin/copilot-node-server` (with `node`).

If you have any Copilot issue, please submit it to [Copilot discussions][copilot-discussions].

[copilot.vim]: https://github.com/github/copilot.vim
[copilot-discussions]: https://github.com/orgs/community/discussions/categories/copilot
[copilot-node-server-npm]: https://www.npmjs.com/package/copilot-node-server
